### R code from vignette source 'hapfabia.Rnw'

###################################################
### code chunk number 1: hapfabia.Rnw:77-81
###################################################
options(width=60)
set.seed(0)
library(hapFabia)
hapFabiaVer<-packageDescription("hapFabia")$Version


###################################################
### code chunk number 2: createData
###################################################
library(hapFabia)
library(fabia)
data(simu)
namesL <- simu[[1]]
haploN <- simu[[2]]
snps <- simu[[3]]
annot <- simu[[4]]
alleleIimp <- simu[[5]]
write.table(namesL,file="dataSim1fabia_samples.txt",
    quote = FALSE,row.names = FALSE,col.names = FALSE)
write(as.integer(haploN),file="dataSim1fabia_annot.txt",
    ncolumns=100)
write(as.integer(snps),file="dataSim1fabia_annot.txt",
    append=TRUE,ncolumns=100)
write.table(annot,file="dataSim1fabia_annot.txt", sep = " ",
    quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)
write(as.integer(haploN),file="dataSim1fabia_mat.txt",ncolumns=100)
write(as.integer(snps),file="dataSim1fabia_mat.txt",
    append=TRUE,ncolumns=100)

for (i in 1:haploN) {

  a1 <- which(alleleIimp[i,]>0.01)

  al <- length(a1)
  b1 <- alleleIimp[i,a1]

  a1 <- a1 - 1
  dim(a1) <- c(1,al)
  b1 <- format(as.double(b1),nsmall=1)
  dim(b1) <- c(1,al)

  write.table(al,file="dataSim1fabia_mat.txt", sep = " ",
     quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)
  write.table(a1,file="dataSim1fabia_mat.txt", sep = " ",
     quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)
  write.table(b1,file="dataSim1fabia_mat.txt", sep = " ",
     quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)

}


###################################################
### code chunk number 3: callHapFabia
###################################################
hapRes <- hapFabia(fileName="dataSim1fabia",prefixPath="",
     upperBP=0.15,p=10,iter=1,IBDlength=10,pMAF=0.1)


###################################################
### code chunk number 4: assignHaplotypeList
###################################################
mergedIBD <- hapRes$mergedIBD # $


###################################################
### code chunk number 5: plotHaplotype
###################################################
plotOneIBD(mergedIBD,filename="dataSim1fabia_mat",ibdC=1)


###################################################
### code chunk number 6: removeData
###################################################
unlink("dataSim1fabia_mat.txt")
unlink("dataSim1fabia_annot.txt")
unlink("dataSim1fabia_samples.txt")
unlink("dataSim1fabia_resIBD.Rda")
unlink("dataSim1fabia_mat_res_L.txt")
unlink("dataSim1fabia_mat_res_lapla.txt")
unlink("dataSim1fabia_mat_res_Psi.txt")
unlink("dataSim1fabia_mat_res_Z.txt")
unlink("dataSim1fabia_mat_res_Z_full.txt")


###################################################
### code chunk number 7: secondExampleData
###################################################
simulateForFabia(minruns=2,maxruns=2)


###################################################
### code chunk number 8: secondExampleCallHapFabia
###################################################
hapRes <- hapFabia(fileName="dataSim2fabia",prefixPath="",
      upperBP=0.15,p=10,iter=1,IBDlength=10,pMAF=0.1)


###################################################
### code chunk number 9: secondExampleAssignHaplotype
###################################################
mergedIBD <- hapRes$mergedIBD # $


###################################################
### code chunk number 10: secondExamplePlot
###################################################
plotOneIBD(mergedIBD,filename="dataSim2fabia_mat",ibdC=1)


###################################################
### code chunk number 11: secondExampleRemove
###################################################
unlink("dataSim2fabia_mat.txt")
unlink("dataSim2fabia_annot.txt")
unlink("dataSim2fabia_samples.txt")
unlink("dataSim2fabia_resIBD.Rda")
unlink("dataSim2fabia_mat_res_L.txt")
unlink("dataSim2fabia_mat_res_lapla.txt")
unlink("dataSim2fabia_mat_res_Psi.txt")
unlink("dataSim2fabia_mat_res_Z.txt")
unlink("dataSim2fabia_mat_res_Z_full.txt")


###################################################
### code chunk number 12: histograms
###################################################
data(res)
h1 <- histL(res,n=1,p=0.9,intervv=50,off=0)
print(h1$counts)
h1 <- histL(res,n=1,w=0.5,intervv=50,off=0)
print(h1$counts)


###################################################
### code chunk number 13: plotLhistP
###################################################
data(res)
plotL(res,1,p=0.95,type="histogram",intervv=50)


###################################################
### code chunk number 14: plotLpointsP
###################################################
data(res)
plotL(res,1,p=0.95)


###################################################
### code chunk number 15: plotLpointsW
###################################################
data(res)
plotL(res,1,w=0.5)


###################################################
### code chunk number 16: plotLsmoothP
###################################################
data(res)
plotL(res,1,p=0.95,type="smooth")


###################################################
### code chunk number 17: plotLsmoothW
###################################################
data(res)
plotL(res,1,w=0.5,type="smooth")


###################################################
### code chunk number 18: topLZ
###################################################
data(res)

topLZ(res,1,LZ="L",p=0.95)
topLZ(res,1,LZ="L",w=0.95)

topLZ(res,1,LZ="Z",p=0.95)
topLZ(res,1,LZ="Z",w=0.4)

topLZ(res,1,LZ="L",indices=FALSE,p=0.95)
topLZ(res,1,LZ="L",indices=FALSE,w=0.95)

topLZ(res,1,LZ="Z",indices=FALSE,p=0.95)
topLZ(res,1,LZ="Z",indices=FALSE,w=0.4)


